import { BrowserPlugin } from "@snowplow/browser-tracker-core";
import { CommonEventProperties, SelfDescribingJson } from "@snowplow/tracker-core";
/**
 * Type for Consent Action
 */
interface Consent {
    /**
     * The action for the consent preferences of a user
     */
    eventType: "deny_all" | "allow_all" | "allow_selected" | "pending" | "implicit_consent" | "withdrawn" | "expired";
    /**
     * GDPR lawful basis for data collection & processing
     */
    basisForProcessing: "consent" | "contract" | "legal_obligation" | "vital_interests" | "public_task" | "legitimate_interests";
    /**
     * URI of the privacy policy related document
     */
    consentUrl: string;
    /**
     * Version of the privacy policy related document
     */
    consentVersion: string;
    /**
     * The scopes allowed after the user finalized his selection of consent preferences. E.g ['analytics', 'functional', 'advertisement'].
     */
    consentScopes: string[];
    /**
     * The domains for which this consent allows these preferences to persist to.
     */
    domainsApplied: string[];
    /**
     * Determine if GDPR applies based on the user's geo-location.
     */
    gdprApplies?: boolean;
}
interface CmpVisible {
    /**
     * The time between the page load and dialog box appearing
     */
    elapsedTime: number;
}
interface CommonConsentEventProperties extends CommonEventProperties {
    /** Add context to an event by setting an Array of Self Describing JSON */
    context?: Array<SelfDescribingJson>;
}
type ConsentEventProperties = Omit<Consent, "eventType"> & CommonConsentEventProperties;
/**
 * Adds consent tracking
 */
declare function EnhancedConsentPlugin(): BrowserPlugin;
/**
 * Track the loadtime of a CMP banner
 */
declare function trackCmpVisible(cmpVisible: CmpVisible & CommonConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track an allow consent event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentAllow(consent: ConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track an allow selected consent event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentSelected(consent: ConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track a consent pending event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentPending(consent: ConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track an implicit consent event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentImplicit(consent: ConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track a deny consent event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentDeny(consent: ConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track a consent expired event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentExpired(consent: ConsentEventProperties, trackers?: Array<string>): void;
/**
 * Track a consent withdrawn event
 *
 * @param consent - The consent information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackConsentWithdrawn(consent: ConsentEventProperties, trackers?: Array<string>): void;
export { EnhancedConsentPlugin, trackCmpVisible, trackConsentAllow, trackConsentSelected, trackConsentPending, trackConsentImplicit, trackConsentDeny, trackConsentExpired, trackConsentWithdrawn };
